@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Libarchive callbacks
-our $VERSION = '0.0706'; # VERSION
+our $VERSION = '0.0800'; # VERSION
 
 package
   Archive::Libarchive::FFI;
@@ -376,7 +376,7 @@ Archive::Libarchive::FFI::Callback - Libarchive callbacks
 
 =head1 VERSION
 
-version 0.0706
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -470,7 +470,7 @@ L<archive_read_open2|Archive::Libarchive::FFI::Function#archive_read_open2>.
  my $mywrite = sub {
    my($archive, $data, $buffer) = @_;
    ...
-   return $status1;
+   return $bytes_written_or_status;
  };
  my $status2 = archive_write_open($archive, undef, $mywrite, undef);
 
@@ -478,6 +478,9 @@ This callback is called whenever libarchive has data it wants to send
 to output.  The callback itself takes one additional argument, a 
 buffer containing the data to write.
 
+It should return the actual number of bytes written by you, or an
+status value for an error.
+
 =head2 skip
 
  my $status1 = archive_read_set_skip_callback($archive, sub {
